pub struct Convolution2DOpDescriptor { /* private fields */ }Expand description
A class that describes the properties of a 2D-convolution operator.
Use an instance of this class is to add a 2D-convolution operator with the desired properties to the graph.
See also Apple’s documentation
Implementations
Sourceimpl Convolution2DOpDescriptor
impl Convolution2DOpDescriptor
Sourcepub fn stride_in_x(&self) -> u64
pub fn stride_in_x(&self) -> u64
Sourcepub fn set_stride_in_x(&self, stride_in_x: u64)
pub fn set_stride_in_x(&self, stride_in_x: u64)
Sourcepub fn stride_in_y(&self) -> u64
pub fn stride_in_y(&self) -> u64
Sourcepub fn set_stride_in_y(&self, stride_in_y: u64)
pub fn set_stride_in_y(&self, stride_in_y: u64)
Sourcepub fn dilation_rate_in_x(&self) -> u64
pub fn dilation_rate_in_x(&self) -> u64
Returns the amount by which the weights tensor expands in the x direction.
Details
Expansion is achieved by inserting dilationRateInX - 1 zeros between consecutive values
in the x dimension of the weights tensor. The resulting dilated width is
(dilationRateInX - 1) * kernelWidth + 1.
The default value is 1.
Returns
The dilation rate along the x axis.
Sourcepub fn set_dilation_rate_in_x(&self, dilation_rate_in_x: u64)
pub fn set_dilation_rate_in_x(&self, dilation_rate_in_x: u64)
Sourcepub fn dilation_rate_in_y(&self) -> u64
pub fn dilation_rate_in_y(&self) -> u64
Returns the amount by which the weights tensor expands in the y direction.
Details
Expansion is achieved by inserting dilationRateInY - 1 zeros between consecutive values
in the y dimension of the weights tensor. The resulting dilated height is
(dilationRateInY - 1) * kernelHeight + 1.
The default value is 1.
Returns
The dilation rate along the y axis.
Sourcepub fn set_dilation_rate_in_y(&self, dilation_rate_in_y: u64)
pub fn set_dilation_rate_in_y(&self, dilation_rate_in_y: u64)
Sourcepub fn padding_left(&self) -> u64
pub fn padding_left(&self) -> u64
Returns the number of zeros added to the left side of the source tensor.
Returns
The left padding value.
Sourcepub fn set_padding_left(&self, padding_left: u64)
pub fn set_padding_left(&self, padding_left: u64)
Sourcepub fn padding_right(&self) -> u64
pub fn padding_right(&self) -> u64
Returns the number of zeros added to the right side of the source tensor.
Returns
The right padding value.
Sourcepub fn set_padding_right(&self, padding_right: u64)
pub fn set_padding_right(&self, padding_right: u64)
Sourcepub fn padding_top(&self) -> u64
pub fn padding_top(&self) -> u64
Sourcepub fn set_padding_top(&self, padding_top: u64)
pub fn set_padding_top(&self, padding_top: u64)
Sourcepub fn padding_bottom(&self) -> u64
pub fn padding_bottom(&self) -> u64
Returns the number of zeros added to the bottom of the source tensor.
Returns
The bottom padding value.
Sourcepub fn set_padding_bottom(&self, padding_bottom: u64)
pub fn set_padding_bottom(&self, padding_bottom: u64)
Sourcepub fn padding_style(&self) -> PaddingStyle
pub fn padding_style(&self) -> PaddingStyle
Returns the padding style applied to the source tensor.
Details
If the style is PaddingStyle::Explicit, the individual padding
values (padding_left, padding_right, padding_top,
padding_bottom) must be specified. For all other styles, the
framework computes these values automatically.
Returns
The selected PaddingStyle.
Sourcepub fn set_padding_style(&self, padding_style: PaddingStyle)
pub fn set_padding_style(&self, padding_style: PaddingStyle)
Sourcepub fn data_layout(&self) -> TensorNamedDataLayout
pub fn data_layout(&self) -> TensorNamedDataLayout
Returns the named layout of data in the source tensor.
Returns
The current TensorNamedDataLayout for the source tensor.
Sourcepub fn set_data_layout(&self, data_layout: TensorNamedDataLayout)
pub fn set_data_layout(&self, data_layout: TensorNamedDataLayout)
Sets the data_layout property.
Arguments
data_layout– The desired layout of the source tensor data.
Sourcepub fn weights_layout(&self) -> TensorNamedDataLayout
pub fn weights_layout(&self) -> TensorNamedDataLayout
Returns the named layout of data in the weights tensor.
Returns
The current TensorNamedDataLayout for the weights tensor.
Sourcepub fn set_weights_layout(&self, weights_layout: TensorNamedDataLayout)
pub fn set_weights_layout(&self, weights_layout: TensorNamedDataLayout)
Sets the weights_layout property.
Arguments
weights_layout– The desired layout of the weights tensor data.
Sourcepub fn set_groups(&self, groups: u64)
pub fn set_groups(&self, groups: u64)
Sourcepub fn descriptor_with_stride_in_x_stride_in_y_dilation_rate_in_x_dilation_rate_in_y_groups_padding_left_padding_right_padding_top_padding_bottom_padding_style_data_layout_weights_layout(
stride_in_x: u64,
stride_in_y: u64,
dilation_rate_in_x: u64,
dilation_rate_in_y: u64,
groups: u64,
padding_left: u64,
padding_right: u64,
padding_top: u64,
padding_bottom: u64,
padding_style: PaddingStyle,
data_layout: TensorNamedDataLayout,
weights_layout: TensorNamedDataLayout,
) -> Option<Retained<Self>>
pub fn descriptor_with_stride_in_x_stride_in_y_dilation_rate_in_x_dilation_rate_in_y_groups_padding_left_padding_right_padding_top_padding_bottom_padding_style_data_layout_weights_layout( stride_in_x: u64, stride_in_y: u64, dilation_rate_in_x: u64, dilation_rate_in_y: u64, groups: u64, padding_left: u64, padding_right: u64, padding_top: u64, padding_bottom: u64, padding_style: PaddingStyle, data_layout: TensorNamedDataLayout, weights_layout: TensorNamedDataLayout, ) -> Option<Retained<Self>>
Creates a convolution descriptor with the supplied parameter values.
Arguments
stride_in_x– Seestride_in_x.stride_in_y– Seestride_in_y.dilation_rate_in_x– Seedilation_rate_in_x.dilation_rate_in_y– Seedilation_rate_in_y.groups– Seegroups.padding_left– Seepadding_left.padding_right– Seepadding_right.padding_top– Seepadding_top.padding_bottom– Seepadding_bottom.padding_style– Seepadding_style.data_layout– Seedata_layout.weights_layout– Seeweights_layout.
Returns
A new MPSGraphConvolution2DOpDescriptor.
Sourcepub fn descriptor_with_stride_in_x_stride_in_y_dilation_rate_in_x_dilation_rate_in_y_groups_padding_style_data_layout_weights_layout(
stride_in_x: u64,
stride_in_y: u64,
dilation_rate_in_x: u64,
dilation_rate_in_y: u64,
groups: u64,
padding_style: PaddingStyle,
data_layout: TensorNamedDataLayout,
weights_layout: TensorNamedDataLayout,
) -> Option<Retained<Self>>
pub fn descriptor_with_stride_in_x_stride_in_y_dilation_rate_in_x_dilation_rate_in_y_groups_padding_style_data_layout_weights_layout( stride_in_x: u64, stride_in_y: u64, dilation_rate_in_x: u64, dilation_rate_in_y: u64, groups: u64, padding_style: PaddingStyle, data_layout: TensorNamedDataLayout, weights_layout: TensorNamedDataLayout, ) -> Option<Retained<Self>>
Creates a convolution descriptor with the supplied parameter values.
Arguments
stride_in_x– Seestride_in_x.stride_in_y– Seestride_in_y.dilation_rate_in_x– Seedilation_rate_in_x.dilation_rate_in_y– Seedilation_rate_in_y.groups– Seegroups.padding_style– Seepadding_style.data_layout– Seedata_layout.weights_layout– Seeweights_layout.
Returns
A new MPSGraphConvolution2DOpDescriptor.
Sourcepub fn set_explicit_padding_with_padding_left_padding_right_padding_top_padding_bottom(
&self,
padding_left: u64,
padding_right: u64,
padding_top: u64,
padding_bottom: u64,
)
pub fn set_explicit_padding_with_padding_left_padding_right_padding_top_padding_bottom( &self, padding_left: u64, padding_right: u64, padding_top: u64, padding_bottom: u64, )
Sets the explicit padding values on all sides of the source tensor.
Arguments
padding_left– Seepadding_left.padding_right– Seepadding_right.padding_top– Seepadding_top.padding_bottom– Seepadding_bottom.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for Convolution2DOpDescriptor
impl AsRef<AnyObject> for Convolution2DOpDescriptor
Sourceimpl AsRef<GraphObject> for Convolution2DOpDescriptor
impl AsRef<GraphObject> for Convolution2DOpDescriptor
Sourcefn as_ref(&self) -> &GraphObject
fn as_ref(&self) -> &GraphObject
Sourceimpl AsRef<NSObject> for Convolution2DOpDescriptor
impl AsRef<NSObject> for Convolution2DOpDescriptor
Sourceimpl Borrow<AnyObject> for Convolution2DOpDescriptor
impl Borrow<AnyObject> for Convolution2DOpDescriptor
Sourceimpl Borrow<GraphObject> for Convolution2DOpDescriptor
impl Borrow<GraphObject> for Convolution2DOpDescriptor
Sourcefn borrow(&self) -> &GraphObject
fn borrow(&self) -> &GraphObject
Sourceimpl Borrow<NSObject> for Convolution2DOpDescriptor
impl Borrow<NSObject> for Convolution2DOpDescriptor
Sourceimpl ClassType for Convolution2DOpDescriptor
impl ClassType for Convolution2DOpDescriptor
Sourceconst NAME: &'static str = "Convolution2DOpDescriptor"
const NAME: &'static str = "Convolution2DOpDescriptor"
Sourcetype Super = GraphObject
type Super = GraphObject
Sourcetype ThreadKind = <<Convolution2DOpDescriptor as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<Convolution2DOpDescriptor as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl CopyingHelper for Convolution2DOpDescriptor
impl CopyingHelper for Convolution2DOpDescriptor
Sourcetype Result = Convolution2DOpDescriptor
type Result = Convolution2DOpDescriptor
Self if the type has no
immutable counterpart. Read moreSourceimpl Debug for Convolution2DOpDescriptor
impl Debug for Convolution2DOpDescriptor
Sourceimpl Deref for Convolution2DOpDescriptor
impl Deref for Convolution2DOpDescriptor
Sourceimpl Hash for Convolution2DOpDescriptor
impl Hash for Convolution2DOpDescriptor
Sourceimpl Message for Convolution2DOpDescriptor
impl Message for Convolution2DOpDescriptor
Sourceimpl NSCopying for Convolution2DOpDescriptor
impl NSCopying for Convolution2DOpDescriptor
Sourceimpl NSObjectProtocol for Convolution2DOpDescriptor
impl NSObjectProtocol for Convolution2DOpDescriptor
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref